@@ -41,15 +41,24 @@ class Label(TagMixin):
         self.text = text
         super(Label, self).__init__(**kwargs)
 
-    def render(self, field):
+    def render(self, field=None, **kwargs):
         attrs = self.attributes.copy()
-        if not 'id' in field.attributes and field.name:
+        if 'text' in kwargs:
+            self.text = kwargs['text']
+            del kwargs['text']
+        if 'for_' in kwargs:
+            attrs['for'] = kwargs['for_']
+            del kwargs['for_']
+        attrs.update(kwargs)
+        if field and 'id' not in field.attributes and field.name:
             # inject id based on field name
             id = field.name
             field.attributes['id'] = id
             attrs['for'] = id
         return self.html.format(flatten_attributes(attrs), self.text)
 
+    __call__ = render
+
 
 class FieldMixin(TagMixin):
 
@@ -62,7 +71,8 @@ class FieldMixin(TagMixin):
     Attributes:
         label (watson.form.fields.Label): the label associated with the field
         html (string): the html used to render the field
-        validators (list): the validators that will be used to validate the value
+        validators (list): the validators that will be used to validate the
+                           value.
         filters (list): the filters that will be used prior to validation
     """
     _counter = itertools.count()
@@ -72,6 +82,7 @@ class FieldMixin(TagMixin):
     filters = None
     _errors = None
     _value = None
+    _default_value = None
     _original_value = None
 
     def __new__(cls, definition=True, *args, **kwargs):
@@ -79,7 +90,7 @@ class FieldMixin(TagMixin):
             return Definition(cls, *args, **kwargs)
         return super(FieldMixin, cls).__new__(cls)
 
-    def __init__(self, name=None, value=None,
+    def __init__(self, name=None, value=None, default_value=None,
                  label=None, label_attrs=None, **kwargs):
         """Initializes the field with a specific name.
         """
@@ -91,6 +102,7 @@ class FieldMixin(TagMixin):
             self.label.attributes.update(label_attrs)
         kwargs['name'] = name
         self.value = value
+        self.default_value = default_value
         self.filters = [filters_.Trim()] + kwargs.get('filters', [])
         self.validators = kwargs.get('validators', [])
         if 'validators' in kwargs:
@@ -124,6 +136,15 @@ class FieldMixin(TagMixin):
         """
         self._value = value
 
+    @property
+    def default_value(self):
+        return self._default_value
+
+    @default_value.setter
+    def default_value(self, value):
+        if not self.value:
+            self.value = value
+
     @property
     def original_value(self):
         """Return the original value for the field.
@@ -134,7 +155,8 @@ class FieldMixin(TagMixin):
         """Filter the value on the field based on the associated filters.
 
         Set the original_value of the field to the first value stored. Note, if
-        this is called a second time, then the original value will be overridden.
+        this is called a second time, then the original value will be
+        overridden.
         """
         for _filter in self.filters:
             self._original_value = self.value
@@ -181,6 +203,9 @@ class FieldMixin(TagMixin):
     def __str__(self):
         return self.render()
 
+    def __call__(self, **kwargs):
+        return self.render(**kwargs)
+
     def __repr__(self):
         return '<{0} name:{1}>'.format(get_qualified_name(self), self.name)
 
@@ -268,9 +293,11 @@ class GroupInputMixin(Input):
             attributes.update(kwargs)
             if value:
                 attributes['value'] = value
-            if isinstance(self.value, (list, tuple)) and value in self.value:
-                attributes['checked'] = 'checked'
-            elif self.value and value == self.value:
+            value = str(value)
+            if isinstance(self.value, (list, tuple)):
+                if value in (str(val) for val in self.value):
+                    attributes['checked'] = 'checked'
+            elif self.value and value == str(self.value):
                 attributes['checked'] = 'checked'
             flat_attributes = flatten_attributes(attributes)
             element = self.__render_input(
